// VinciaAntennaSet.cc is a part of the VINCIA plug-in to the PYTHIA 8 
// generator.
// VINCIA is licenced under the GNU GPL version 2.
// Copyright (C) 2013 P. Skands.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// Include the VinciaAntennaSet header file
#include "VinciaAntennaSet.h"

using namespace Pythia8;

namespace Vincia {
  
  //**********************************************************************
  //==========================================================================
  //AntennaSet Methods

  void AntennaSet::init(bool isSectorIn, int variation) {

    if (! isInitPtr) {
      printOut("AntennaSet::init","Cannot initialize, pointers not set.");
      return;
    }
    
    // Set verbose level
    verbose = settingsPtr->mode("Vincia:verbose");

    // Create antenna objects
    antPtrs.resize(5);
    antPtrs[iQQemit] = new QQEmit();
    antPtrs[iQGemit] = new QGEmit();
    antPtrs[iGGemit] = new GGEmit();
    antPtrs[iQGsplit] = new QGSplit();
    antPtrs[iGGsplit] = new GGSplit();
    
    // Loop through antPtrs and initialise
    for (vector<Antenna*>::iterator antPtrIt = antPtrs.begin(); 
         antPtrIt != antPtrs.end(); ++antPtrIt) {

      // Initialize antenna pointers to PYTHIA 8 objects
      (*antPtrIt)->initPtr(functionsPtr, particleDataPtr, rndmPtr, settingsPtr);
      
      // Initialize antenna itself
      bool pass = (*antPtrIt)->init(isSectorIn,variation);
      
      // Optionally check antenna (singularities, positivity, etc)
      if (settingsPtr->flag("Vincia:checkAntennae")) 
	pass = pass && (*antPtrIt)->check();
      
      // Everything OK?
      if (pass) {	
        if (verbose >= 2)
          printOut("Vincia:AntennaSet:init","Added to antenna list: "
                   +(*antPtrIt)->humanName());
      } 
      else if (verbose >= 1) {
        printErr("Vincia:AntennaSet:init","Added to antenna list: "
                 +(*antPtrIt)->humanName()+
		 " (but one or more consistency checks failed");
      }
    }
  }
} // End namespace Vincia
